#!/usr/bin/python3
# -*- coding: utf-8 -*-
""" Export fragments of master SVG image

Pierre Haessig — January 2020, 2022
"""

import subprocess
import shutil
from pathlib import Path

master = 'BG.svg'

# Query all graphical elements
query = subprocess.check_output(['inkscape', '--query-all', master]).decode('utf-8')

X_list = []
R_list = []

# Find elements starting with X- or R-
for l in query.split('\n'):
    if l.startswith('X-'):
        elem = l.split(',')[0][2:]
        X_list.append(elem)
    elif l.startswith('R-'):
        elem = l.split(',')[0][2:]
        R_list.append(elem)


# X_list = ['Ex_E1_diag']
# R_list = []


def export(elem, dpi=254, force=False):
    """export `X-elem` out of `master` file, as SVG and PNG"""
    print(f'Exporting element X-{elem}')
    export_svg(elem, force)
    export_png(elem, dpi, force)


def export_svg(elem, force=False):
    """export `X-elem` out of `master` file, as SVG"""
    fname = elem + '.svg'

    # do not export existing files unless force=True
    if Path(fname).is_file() and not force:
        print(f'  1. Skipping {fname} export (already existing)')
        return

    # 0) Make a copy of the master SVG file
    shutil.copy(master, fname)

    if elem in R_list:
        print(f'  1. Adjust canvas size to R-{elem} and delete all objects other than X-{elem}')
        actions = [
            f'select-by-id:R-{elem}',
            'FitCanvasToSelection',
            'select-clear',
            f'select-by-id:X-{elem}',
            'select-invert:no-layers',
            'EditDelete',
            'FileVacuum',
            'FileSave',
            'FileQuit'
        ]
    
    else: # no rectangle
        print(f'  1. Adjust canvas size and delete all objects other than X-{elem}')
        actions = [
            f'select-by-id:X-{elem}',
            'FitCanvasToSelection',
            'select-invert:no-layers',
            'EditDelete',
            'FileVacuum',
            'FileSave',
            'FileQuit'
        ]
    # end if rectangle
    actions = '; '.join(actions)
    subprocess.run([
        'inkscape', fname, '--with-gui', # GUI needed for verbs (aka CamelCase actions)
        f'--actions={actions}'
    ])


def export_png(elem, dpi=254, force=False):
    """export `X-elem`.svg file as PNG"""
    fname = elem + '.svg'
    fname_png = Path('png') / (elem + '.png')

    # do not export existing files unless force=True
    if Path(fname_png).is_file() and not force:
        print(f'  2. Skipping {fname_png} export (already existing)')
        return

    print(f'  2. Export PNG image ({dpi:d} dpi)')
    subprocess.run([
        'inkscape', fname,
        f'--export-dpi={dpi:d}',
        f'--export-png={fname_png}',
    ])


for elem in X_list:
    print(elem + ' (with rect)' if elem in R_list else '')
    export(elem)
